==> openshift-model-5.7.4-sources.jar: io/fabric8/openshift/api/model/LifecycleHookBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class LifecycleHookBuilder extends io.fabric8.openshift.api.model.LifecycleHookFluentImpl<io.fabric8.openshift.api.model.LifecycleHookBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.LifecycleHook,io.fabric8.openshift.api.model.LifecycleHookBuilder>{
  public LifecycleHookBuilder() {
    this(false);
  }
  public LifecycleHookBuilder(java.lang.Boolean validationEnabled) {
    this(new LifecycleHook(), validationEnabled);
  }
  public LifecycleHookBuilder(io.fabric8.openshift.api.model.LifecycleHookFluent<?> fluent) {
    this(fluent, false);
  }
  public LifecycleHookBuilder(io.fabric8.openshift.api.model.LifecycleHookFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new LifecycleHook(), validationEnabled);
  }
  public LifecycleHookBuilder(io.fabric8.openshift.api.model.LifecycleHookFluent<?> fluent,io.fabric8.openshift.api.model.LifecycleHook instance) {
    this(fluent, instance, false);
  }
  public LifecycleHookBuilder(io.fabric8.openshift.api.model.LifecycleHookFluent<?> fluent,io.fabric8.openshift.api.model.LifecycleHook instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withExecNewPod(instance.getExecNewPod()); 
    fluent.withFailurePolicy(instance.getFailurePolicy()); 
    fluent.withTagImages(instance.getTagImages()); 
    this.validationEnabled = validationEnabled; 
  }
  public LifecycleHookBuilder(io.fabric8.openshift.api.model.LifecycleHook instance) {
    this(instance,false);
  }
  public LifecycleHookBuilder(io.fabric8.openshift.api.model.LifecycleHook instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withExecNewPod(instance.getExecNewPod()); 
    this.withFailurePolicy(instance.getFailurePolicy()); 
    this.withTagImages(instance.getTagImages()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.LifecycleHookFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.LifecycleHook build() {
    LifecycleHook buildable = new LifecycleHook(fluent.getExecNewPod(),fluent.getFailurePolicy(),fluent.getTagImages());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LifecycleHookBuilder that = (LifecycleHookBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.0-sources.jar: io/fabric8/openshift/api/model/LifecycleHookBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class LifecycleHookBuilder extends io.fabric8.openshift.api.model.LifecycleHookFluentImpl<io.fabric8.openshift.api.model.LifecycleHookBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.LifecycleHook,io.fabric8.openshift.api.model.LifecycleHookBuilder>{
  public LifecycleHookBuilder() {
    this(false);
  }
  public LifecycleHookBuilder(java.lang.Boolean validationEnabled) {
    this(new LifecycleHook(), validationEnabled);
  }
  public LifecycleHookBuilder(io.fabric8.openshift.api.model.LifecycleHookFluent<?> fluent) {
    this(fluent, false);
  }
  public LifecycleHookBuilder(io.fabric8.openshift.api.model.LifecycleHookFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new LifecycleHook(), validationEnabled);
  }
  public LifecycleHookBuilder(io.fabric8.openshift.api.model.LifecycleHookFluent<?> fluent,io.fabric8.openshift.api.model.LifecycleHook instance) {
    this(fluent, instance, false);
  }
  public LifecycleHookBuilder(io.fabric8.openshift.api.model.LifecycleHookFluent<?> fluent,io.fabric8.openshift.api.model.LifecycleHook instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withExecNewPod(instance.getExecNewPod()); 
    fluent.withFailurePolicy(instance.getFailurePolicy()); 
    fluent.withTagImages(instance.getTagImages()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public LifecycleHookBuilder(io.fabric8.openshift.api.model.LifecycleHook instance) {
    this(instance,false);
  }
  public LifecycleHookBuilder(io.fabric8.openshift.api.model.LifecycleHook instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withExecNewPod(instance.getExecNewPod()); 
    this.withFailurePolicy(instance.getFailurePolicy()); 
    this.withTagImages(instance.getTagImages()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.LifecycleHookFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.LifecycleHook build() {
    LifecycleHook buildable = new LifecycleHook(fluent.getExecNewPod(),fluent.getFailurePolicy(),fluent.getTagImages());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LifecycleHookBuilder that = (LifecycleHookBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
